@@ -571,7 +571,11 @@ func fillCheckBoxKid(ctx *model.Context, kids types.Array, off bool) (*types.Nam
 		return nil, errors.New("pdfcpu: corrupt AP field: missing entry N")
 	}
 
-	offName, yesName := primitives.CalcCheckBoxASNames(d2)
+	offName, yesName, err := primitives.CalcCheckBoxASNames(ctx, d2)
+	if err != nil {
+		return nil, err
+	}
+
 	asName := yesName
 	if off {
 		asName = offName
@@ -588,7 +592,6 @@ func fillCheckBox(
 	ctx *model.Context,
 	d types.Dict,
 	id, name string,
-	opts []string,
 	locked bool,
 	format DataFormat,
 	fillDetails func(id, name string, fieldType FieldType, format DataFormat) ([]string, bool, bool),
@@ -639,7 +642,10 @@ func fillCheckBox(
 
 	d["V"] = v
 	if _, found := d.Find("AS"); found {
-		offName, yesName := primitives.CalcCheckBoxASNames(d)
+		offName, yesName, err := primitives.CalcCheckBoxASNames(ctx, d)
+		if err != nil {
+			return err
+		}
 		//fmt.Printf("off:<%s> yes:<%s>\n", offName, yesName)
 		asName := yesName
 		if v == "Off" {
@@ -676,7 +682,7 @@ func fillBtn(
 			return err
 		}
 	} else {
-		if err := fillCheckBox(ctx, d, id, name, opts, locked, format, fillDetails, ok); err != nil {
+		if err := fillCheckBox(ctx, d, id, name, locked, format, fillDetails, ok); err != nil {
 			return err
 		}
 	}
@@ -700,6 +706,8 @@ func fillComboBox(
 		return nil
 	}
 
+	da := d.StringEntry("DA")
+
 	vNew := vv[0]
 	if locked {
 		if !lock {
@@ -709,7 +717,7 @@ func fillComboBox(
 		}
 	} else if lock {
 		lockFormField(d)
-		if err := primitives.EnsureComboBoxAP(ctx, d, vNew, fonts); err != nil {
+		if err := primitives.EnsureComboBoxAP(ctx, d, vNew, da, fonts); err != nil {
 			return err
 		}
 		*ok = true
@@ -856,7 +864,9 @@ func fillListBox(
 		return err
 	}
 
-	if err := primitives.EnsureListBoxAP(ctx, d, opts, ind, fonts); err != nil {
+	da := d.StringEntry("DA")
+
+	if err := primitives.EnsureListBoxAP(ctx, d, opts, ind, da, fonts); err != nil {
 		return err
 	}
 
@@ -924,6 +934,7 @@ func fillDateField(
 	}
 
 	vNew := vv[0]
+
 	if vNew == vOld {
 		return nil
 	}
@@ -932,15 +943,35 @@ func fillDateField(
 	if err != nil {
 		return err
 	}
-
 	d["V"] = types.StringLiteral(*s)
 
-	if err := primitives.EnsureDateFieldAP(ctx, d, vNew, fonts); err != nil {
+	da := d.StringEntry("DA")
+
+	kids := d.ArrayEntry("Kids")
+	if len(kids) > 0 {
+
+		for _, o := range kids {
+
+			d, err := ctx.DereferenceDict(o)
+			if err != nil {
+				return err
+			}
+
+			if err := primitives.EnsureDateFieldAP(ctx, d, vNew, da, fonts); err != nil {
+				return err
+			}
+
+			*ok = true
+		}
+
+		return nil
+	}
+
+	if err := primitives.EnsureDateFieldAP(ctx, d, vNew, da, fonts); err != nil {
 		return err
 	}
 
 	*ok = true
-
 	return nil
 }
 
@@ -989,15 +1020,16 @@ func fillTextField(
 	comb := ff != nil && primitives.FieldFlags(*ff)&primitives.FieldComb > 0
 
 	maxLen := 0
+	i := d.IntEntry("MaxLen")
+	if i != nil {
+		maxLen = *i
+	}
+
+	da := d.StringEntry("DA")
 
 	kids := d.ArrayEntry("Kids")
 	if len(kids) > 0 {
 
-		i := d.IntEntry("MaxLen")
-		if i != nil {
-			maxLen = *i
-		}
-
 		for _, o := range kids {
 
 			d, err := ctx.DereferenceDict(o)
@@ -1005,7 +1037,7 @@ func fillTextField(
 				return err
 			}
 
-			if err := primitives.EnsureTextFieldAP(ctx, d, vNew, multiLine, comb, maxLen, fonts); err != nil {
+			if err := primitives.EnsureTextFieldAP(ctx, d, vNew, multiLine, comb, maxLen, da, fonts); err != nil {
 				return err
 			}
 
@@ -1015,7 +1047,7 @@ func fillTextField(
 		return nil
 	}
 
-	if err := primitives.EnsureTextFieldAP(ctx, d, vNew, multiLine, comb, maxLen, fonts); err != nil {
+	if err := primitives.EnsureTextFieldAP(ctx, d, vNew, multiLine, comb, maxLen, da, fonts); err != nil {
 		return err
 	}
 
@@ -1038,6 +1070,7 @@ func fillTx(
 	if err != nil {
 		return err
 	}
+
 	vOld := ""
 	if o, found := d.Find("V"); found {
 		s, err := types.StringOrHexLiteral(o)
@@ -1143,7 +1176,7 @@ func setupFillFonts(xRefTable *model.XRefTable) error {
 
 	for k, v := range d {
 		indRef := v.(types.IndirectRef)
-		fontName, _, err := primitives.FormFontNameAndLangForID(xRefTable, indRef)
+		fontName, _, _, err := primitives.FormFontDetails(xRefTable, indRef)
 		if err != nil {
 			return err
 		}
