@@ -188,6 +188,7 @@ type XRefTable struct {
 }
 
 // NewXRefTable creates a new XRefTable.
+// TODO Export
 func newXRefTable(conf *Configuration) (xRefTable *XRefTable) {
 	return &XRefTable{
 		Table:             map[int]*XRefTableEntry{},
@@ -1793,7 +1794,7 @@ func (xRefTable *XRefTable) checkInheritedPageAttrs(pageDict types.Dict, pAttrs
 }
 
 // PageContent returns the content in PDF syntax for page dict d.
-func (xRefTable *XRefTable) PageContent(d types.Dict) ([]byte, error) {
+func (xRefTable *XRefTable) PageContent(d types.Dict, pageNr int) ([]byte, error) {
 	o, _ := d.Find("Contents")
 	if o == nil {
 		return nil, ErrNoContent
@@ -1815,7 +1816,7 @@ func (xRefTable *XRefTable) PageContent(d types.Dict) ([]byte, error) {
 			return nil, errors.New("pdfcpu: unsupported filter: unable to decode content")
 		}
 		if err != nil {
-			return nil, err
+			return nil, errors.Errorf("page %d content decode: %v", pageNr, err)
 		}
 
 		bb = append(bb, o.Content...)
@@ -1828,7 +1829,7 @@ func (xRefTable *XRefTable) PageContent(d types.Dict) ([]byte, error) {
 			}
 			o, _, err := xRefTable.DereferenceStreamDict(o)
 			if err != nil {
-				return nil, err
+				return nil, errors.Errorf("page %d content decode: %v", pageNr, err)
 			}
 			if o == nil {
 				continue
@@ -1838,7 +1839,7 @@ func (xRefTable *XRefTable) PageContent(d types.Dict) ([]byte, error) {
 				return nil, errors.New("pdfcpu: unsupported filter: unable to decode content")
 			}
 			if err != nil {
-				return nil, err
+				return nil, errors.Errorf("page %d content decode: %v", pageNr, err)
 			}
 			bb = append(bb, o.Content...)
 		}
@@ -1897,12 +1898,12 @@ func consolidateResourceDict(d types.Dict, prn PageResourceNames, pageNr int) er
 	return nil
 }
 
-func (xRefTable *XRefTable) consolidateResourcesWithContent(pageDict, resDict types.Dict, page int, consolidateRes bool) error {
+func (xRefTable *XRefTable) consolidateResourcesWithContent(pageDict, resDict types.Dict, pageNr int, consolidateRes bool) error {
 	if !consolidateRes {
 		return nil
 	}
 
-	bb, err := xRefTable.PageContent(pageDict)
+	bb, err := xRefTable.PageContent(pageDict, pageNr)
 	if err != nil {
 		if err == ErrNoContent {
 			return nil
@@ -1920,7 +1921,7 @@ func (xRefTable *XRefTable) consolidateResourcesWithContent(pageDict, resDict ty
 	// Remove any resource that's not required.
 	// Return an error for any required resource missing.
 	// TODO Calculate and accumulate resources required by content streams of any present form or type 3 fonts.
-	return consolidateResourceDict(resDict, prn, page)
+	return consolidateResourceDict(resDict, prn, pageNr)
 }
 
 func (xRefTable *XRefTable) pageObjType(indRef types.IndirectRef) (string, error) {
@@ -2057,6 +2058,10 @@ func (xRefTable *XRefTable) PageDict(pageNr int, consolidateRes bool) (types.Dic
 		return nil, nil, nil, err
 	}
 
+	if consolidateRes {
+		consolidateRes = xRefTable.Conf.OptimizeResourceDicts
+	}
+
 	// Calculate and return only resources that are really needed by
 	// any content stream of this page and any possible forms or type 3 fonts referenced.
 	pageDict, pageDictindRef, err := xRefTable.processPageTreeForPageDict(pageRootDictIndRef, &inhPAttrs, &pageCount, pageNr, consolidateRes)
