@@ -77,7 +77,7 @@ func removeEmptyContentStreams(ctx *model.Context, pageDict types.Dict, obj type
 		contentStreamDict, ok := entry.Object.(types.StreamDict)
 		if ok {
 			if err := contentStreamDict.Decode(); err != nil {
-				return err
+				return errors.Errorf("invalid content stream obj#%d: %v", pageObjNumber, err)
 			}
 			if len(contentStreamDict.Content) == 0 {
 				pageDict.Delete("Contents")
@@ -142,10 +142,6 @@ func optimizePageContent(ctx *model.Context, pageDict types.Dict, pageObjNumber
 		return nil
 	}
 
-	if !ctx.OptimizeDuplicateContentStreams {
-		return nil
-	}
-
 	if log.OptimizeEnabled() {
 		log.Optimize.Println("identifyPageContent begin")
 	}
@@ -341,7 +337,7 @@ func registerFontDictObjNr(ctx *model.Context, fName string, objNr int) {
 }
 
 // Get rid of redundant fonts for given fontResources dictionary.
-func optimizeFontResourcesDict(ctx *model.Context, rDict types.Dict, pageNr, pageObjNumber int, rNamePrefix string) error {
+func optimizeFontResourcesDict(ctx *model.Context, rDict types.Dict, pageNr int, rNamePrefix string) error {
 	pageFonts := pageFonts(ctx, pageNr)
 
 	// Iterate over font resource dict.
@@ -717,7 +713,7 @@ func optimizeResources(ctx *model.Context, resourcesDict types.Dict, pageNr, pag
 			return errors.Errorf("pdfcpu: optimizeResources: font resource dict is null for page %d pageObj %d\n", pageNr, pageObjNumber)
 		}
 
-		if err = optimizeFontResourcesDict(ctx, d, pageNr, pageObjNumber, rNamePrefix); err != nil {
+		if err = optimizeFontResourcesDict(ctx, d, pageNr, rNamePrefix); err != nil {
 			return err
 		}
 
@@ -790,15 +786,11 @@ func parseResourcesDict(ctx *model.Context, pageDict types.Dict, pageNr, pageObj
 func parsePagesDict(ctx *model.Context, pagesDict types.Dict, pageNr int) (int, error) {
 	// TODO Integrate resource consolidation based on content stream requirements.
 
-	count, found := pagesDict.Find("Count")
+	_, found := pagesDict.Find("Count")
 	if !found {
 		return pageNr, errors.New("pdfcpu: parsePagesDict: missing Count")
 	}
 
-	if log.OptimizeEnabled() {
-		log.Optimize.Printf("parsePagesDict begin (next page=%d has %s pages): %s\n", pageNr+1, count.(types.Integer), pagesDict)
-	}
-
 	ctx.Optimize.Cache = map[int]bool{}
 
 	// Iterate over page tree.
@@ -843,8 +835,10 @@ func parsePagesDict(ctx *model.Context, pagesDict types.Dict, pageNr int) (int,
 
 		// Process page dict.
 
-		if err = optimizePageContent(ctx, d, int(ir.ObjectNumber)); err != nil {
-			return 0, err
+		if ctx.OptimizeDuplicateContentStreams {
+			if err = optimizePageContent(ctx, d, int(ir.ObjectNumber)); err != nil {
+				return 0, err
+			}
 		}
 
 		if err := ctx.DeleteDictEntry(d, "PieceInfo"); err != nil {
