@@ -23,7 +23,6 @@ import (
 
 	"github.com/pdfcpu/pdfcpu/pkg/font"
 	"github.com/pdfcpu/pdfcpu/pkg/pdfcpu/color"
-	pdffont "github.com/pdfcpu/pdfcpu/pkg/pdfcpu/font"
 	"github.com/pdfcpu/pdfcpu/pkg/pdfcpu/model"
 	"github.com/pdfcpu/pdfcpu/pkg/pdfcpu/types"
 	"github.com/pkg/errors"
@@ -232,38 +231,15 @@ func (cb *ComboBox) validate() error {
 	return cb.validateTab()
 }
 
-func (cb *ComboBox) calcFontFromDA(ctx *model.Context, d types.Dict, fonts map[string]types.IndirectRef) (*types.IndirectRef, error) {
-
-	s := d.StringEntry("DA")
-	if s == nil {
-		s = ctx.Form.StringEntry("DA")
-		if s == nil {
-			return nil, errors.New("pdfcpu: combobox missing \"DA\"")
-		}
-	}
-
-	fontID, f, err := fontFromDA(*s)
+func (cb *ComboBox) calcFontFromDA(ctx *model.Context, d types.Dict, da *string, fonts map[string]types.IndirectRef) (*types.IndirectRef, error) {
+	id, font, rtl, fontIndRef, err := calcFontDetailsFromDA(ctx, d, da, false, fonts)
 	if err != nil {
 		return nil, err
 	}
 
-	cb.Font, cb.fontID = &f, fontID
-
-	id, name, lang, fontIndRef, err := extractFormFontDetails(ctx, cb.fontID, fonts)
-	if err != nil {
-		return nil, err
-	}
-	if fontIndRef == nil {
-		return nil, errors.New("pdfcpu: unable to detect indirect reference for font")
-	}
-
-	fillFont := formFontIndRef(ctx.XRefTable, fontID) != nil
-
 	cb.fontID = id
-	cb.Font.Name = name
-	cb.Font.Lang = lang
-	cb.Font.FillFont = fillFont
-	cb.RTL = pdffont.RTL(lang)
+	cb.Font = font
+	cb.RTL = rtl
 
 	return fontIndRef, nil
 }
@@ -723,6 +699,7 @@ func NewComboBox(
 	ctx *model.Context,
 	d types.Dict,
 	v string,
+	da *string,
 	fonts map[string]types.IndirectRef) (*ComboBox, *types.IndirectRef, error) {
 
 	cb := &ComboBox{Value: v}
@@ -734,7 +711,7 @@ func NewComboBox(
 
 	cb.BoundingBox = types.RectForDim(bb.Width(), bb.Height())
 
-	fontIndRef, err := cb.calcFontFromDA(ctx, d, fonts)
+	fontIndRef, err := cb.calcFontFromDA(ctx, d, da, fonts)
 	if err != nil {
 		return nil, nil, err
 	}
@@ -761,9 +738,9 @@ func NewComboBox(
 	return cb, fontIndRef, nil
 }
 
-func renderComboBoxAP(ctx *model.Context, d types.Dict, v string, fonts map[string]types.IndirectRef) error {
+func renderComboBoxAP(ctx *model.Context, d types.Dict, v string, da *string, fonts map[string]types.IndirectRef) error {
 
-	cb, fontIndRef, err := NewComboBox(ctx, d, v, fonts)
+	cb, fontIndRef, err := NewComboBox(ctx, d, v, da, fonts)
 	if err != nil {
 		return err
 	}
@@ -783,9 +760,9 @@ func renderComboBoxAP(ctx *model.Context, d types.Dict, v string, fonts map[stri
 	return nil
 }
 
-func refreshComboBoxAP(ctx *model.Context, d types.Dict, v string, fonts map[string]types.IndirectRef, irN *types.IndirectRef) error {
+func refreshComboBoxAP(ctx *model.Context, d types.Dict, v string, da *string, fonts map[string]types.IndirectRef, irN *types.IndirectRef) error {
 
-	cb, _, err := NewComboBox(ctx, d, v, fonts)
+	cb, _, err := NewComboBox(ctx, d, v, da, fonts)
 	if err != nil {
 		return err
 	}
@@ -798,11 +775,11 @@ func refreshComboBoxAP(ctx *model.Context, d types.Dict, v string, fonts map[str
 	return updateForm(ctx.XRefTable, bb, irN)
 }
 
-func EnsureComboBoxAP(ctx *model.Context, d types.Dict, v string, fonts map[string]types.IndirectRef) error {
+func EnsureComboBoxAP(ctx *model.Context, d types.Dict, v string, da *string, fonts map[string]types.IndirectRef) error {
 
 	apd := d.DictEntry("AP")
 	if apd == nil {
-		return renderComboBoxAP(ctx, d, v, fonts)
+		return renderComboBoxAP(ctx, d, v, da, fonts)
 	}
 
 	irN := apd.IndirectRefEntry("N")
@@ -810,5 +787,5 @@ func EnsureComboBoxAP(ctx *model.Context, d types.Dict, v string, fonts map[stri
 		return nil
 	}
 
-	return refreshComboBoxAP(ctx, d, v, fonts, irN)
+	return refreshComboBoxAP(ctx, d, v, da, fonts, irN)
 }
