@@ -281,37 +281,14 @@ func (df *DateField) validate() error {
 	return df.validateTab()
 }
 
-func (df *DateField) calcFontFromDA(ctx *model.Context, d types.Dict, fonts map[string]types.IndirectRef) (*types.IndirectRef, error) {
-
-	s := d.StringEntry("DA")
-	if s == nil {
-		s = ctx.Form.StringEntry("DA")
-		if s == nil {
-			return nil, errors.New("pdfcpu: datefield missing \"DA\"")
-		}
-	}
-
-	fontID, f, err := fontFromDA(*s)
+func (df *DateField) calcFontFromDA(ctx *model.Context, d types.Dict, da *string, needUTF8 bool, fonts map[string]types.IndirectRef) (*types.IndirectRef, error) {
+	id, font, _, fontIndRef, err := calcFontDetailsFromDA(ctx, d, da, needUTF8, fonts)
 	if err != nil {
 		return nil, err
 	}
 
-	df.Font, df.fontID = &f, fontID
-
-	id, name, lang, fontIndRef, err := extractFormFontDetails(ctx, df.fontID, fonts)
-	if err != nil {
-		return nil, err
-	}
-	if fontIndRef == nil {
-		return nil, errors.New("pdfcpu: unable to detect indirect reference for font")
-	}
-
-	fillFont := formFontIndRef(ctx.XRefTable, fontID) != nil
-
 	df.fontID = id
-	df.Font.Name = name
-	df.Font.Lang = lang
-	df.Font.FillFont = fillFont
+	df.Font = font
 
 	return fontIndRef, nil
 }
@@ -861,6 +838,8 @@ func NewDateField(
 	ctx *model.Context,
 	d types.Dict,
 	v string,
+	da *string,
+	fontIndRef *types.IndirectRef,
 	fonts map[string]types.IndirectRef) (*DateField, *types.IndirectRef, error) {
 
 	df := &DateField{Value: v}
@@ -872,9 +851,10 @@ func NewDateField(
 
 	df.BoundingBox = types.RectForDim(bb.Width(), bb.Height())
 
-	fontIndRef, err := df.calcFontFromDA(ctx, d, fonts)
-	if err != nil {
-		return nil, nil, err
+	if fontIndRef == nil {
+		if fontIndRef, err = df.calcFontFromDA(ctx, d, da, hasUTF(v), fonts); err != nil {
+			return nil, nil, err
+		}
 	}
 
 	df.HorAlign = types.AlignLeft
@@ -899,9 +879,9 @@ func NewDateField(
 	return df, fontIndRef, nil
 }
 
-func renderDateFieldAP(ctx *model.Context, d types.Dict, v string, fonts map[string]types.IndirectRef) error {
+func renderDateFieldAP(ctx *model.Context, d types.Dict, v string, da *string, fonts map[string]types.IndirectRef) error {
 
-	df, fontIndRef, err := NewDateField(ctx, d, v, fonts)
+	df, fontIndRef, err := NewDateField(ctx, d, v, da, nil, fonts)
 	if err != nil {
 		return err
 	}
@@ -921,9 +901,8 @@ func renderDateFieldAP(ctx *model.Context, d types.Dict, v string, fonts map[str
 	return nil
 }
 
-func refreshDateFieldAP(ctx *model.Context, d types.Dict, v string, fonts map[string]types.IndirectRef, irN *types.IndirectRef) error {
-
-	df, _, err := NewDateField(ctx, d, v, fonts)
+func refreshDateFieldAP(ctx *model.Context, d types.Dict, v string, da *string, fonts map[string]types.IndirectRef, irN *types.IndirectRef) error {
+	df, _, err := NewDateField(ctx, d, v, da, nil, fonts)
 	if err != nil {
 		return err
 	}
@@ -936,10 +915,10 @@ func refreshDateFieldAP(ctx *model.Context, d types.Dict, v string, fonts map[st
 	return updateForm(ctx.XRefTable, bb, irN)
 }
 
-func EnsureDateFieldAP(ctx *model.Context, d types.Dict, v string, fonts map[string]types.IndirectRef) error {
+func EnsureDateFieldAP(ctx *model.Context, d types.Dict, v string, da *string, fonts map[string]types.IndirectRef) error {
 	apd := d.DictEntry("AP")
 	if apd == nil {
-		return renderDateFieldAP(ctx, d, v, fonts)
+		return renderDateFieldAP(ctx, d, v, da, fonts)
 	}
 
 	irN := apd.IndirectRefEntry("N")
@@ -947,5 +926,5 @@ func EnsureDateFieldAP(ctx *model.Context, d types.Dict, v string, fonts map[str
 		return nil
 	}
 
-	return refreshDateFieldAP(ctx, d, v, fonts, irN)
+	return refreshDateFieldAP(ctx, d, v, da, fonts, irN)
 }
