@@ -24,7 +24,6 @@ import (
 
 	"github.com/pdfcpu/pdfcpu/pkg/font"
 	"github.com/pdfcpu/pdfcpu/pkg/pdfcpu/color"
-	pdffont "github.com/pdfcpu/pdfcpu/pkg/pdfcpu/font"
 	"github.com/pdfcpu/pdfcpu/pkg/pdfcpu/model"
 	"github.com/pdfcpu/pdfcpu/pkg/pdfcpu/types"
 	"github.com/pkg/errors"
@@ -302,38 +301,15 @@ func (lb *ListBox) validate() error {
 	return lb.validateTab()
 }
 
-func (lb *ListBox) calcFontFromDA(ctx *model.Context, d types.Dict, fonts map[string]types.IndirectRef) (*types.IndirectRef, error) {
-
-	s := d.StringEntry("DA")
-	if s == nil {
-		s = ctx.Form.StringEntry("DA")
-		if s == nil {
-			return nil, errors.New("pdfcpu: listbox missing \"DA\"")
-		}
-	}
-
-	fontID, f, err := fontFromDA(*s)
+func (lb *ListBox) calcFontFromDA(ctx *model.Context, d types.Dict, da *string, fonts map[string]types.IndirectRef) (*types.IndirectRef, error) {
+	id, font, rtl, fontIndRef, err := calcFontDetailsFromDA(ctx, d, da, false, fonts)
 	if err != nil {
 		return nil, err
 	}
 
-	lb.Font, lb.fontID = &f, fontID
-
-	id, name, lang, fontIndRef, err := extractFormFontDetails(ctx, lb.fontID, fonts)
-	if err != nil {
-		return nil, err
-	}
-	if fontIndRef == nil {
-		return nil, errors.New("pdfcpu: unable to detect indirect reference for font")
-	}
-
-	fillFont := formFontIndRef(ctx.XRefTable, fontID) != nil
-
 	lb.fontID = id
-	lb.Font.Name = name
-	lb.Font.Lang = lang
-	lb.Font.FillFont = fillFont
-	lb.RTL = pdffont.RTL(lang)
+	lb.Font = font
+	lb.RTL = rtl
 
 	return fontIndRef, nil
 }
@@ -874,6 +850,7 @@ func NewListBox(
 	d types.Dict,
 	opts []string,
 	ind types.Array,
+	da *string,
 	fonts map[string]types.IndirectRef) (*ListBox, *types.IndirectRef, error) {
 
 	lb := &ListBox{Options: opts, Ind: ind}
@@ -885,7 +862,7 @@ func NewListBox(
 
 	lb.BoundingBox = types.RectForDim(bb.Width(), bb.Height())
 
-	fontIndRef, err := lb.calcFontFromDA(ctx, d, fonts)
+	fontIndRef, err := lb.calcFontFromDA(ctx, d, da, fonts)
 	if err != nil {
 		return nil, nil, err
 	}
@@ -965,9 +942,9 @@ func updateForm(xRefTable *model.XRefTable, bb []byte, indRef *types.IndirectRef
 	return nil
 }
 
-func renderListBoxAP(ctx *model.Context, d types.Dict, opts []string, ind types.Array, fonts map[string]types.IndirectRef) error {
+func renderListBoxAP(ctx *model.Context, d types.Dict, opts []string, ind types.Array, da *string, fonts map[string]types.IndirectRef) error {
 
-	lb, fontIndRef, err := NewListBox(ctx, d, opts, ind, fonts)
+	lb, fontIndRef, err := NewListBox(ctx, d, opts, ind, da, fonts)
 	if err != nil {
 		return err
 	}
@@ -987,9 +964,9 @@ func renderListBoxAP(ctx *model.Context, d types.Dict, opts []string, ind types.
 	return nil
 }
 
-func refreshListBoxAP(ctx *model.Context, d types.Dict, opts []string, ind types.Array, fonts map[string]types.IndirectRef, irN *types.IndirectRef) error {
+func refreshListBoxAP(ctx *model.Context, d types.Dict, opts []string, ind types.Array, da *string, fonts map[string]types.IndirectRef, irN *types.IndirectRef) error {
 
-	lb, _, err := NewListBox(ctx, d, opts, ind, fonts)
+	lb, _, err := NewListBox(ctx, d, opts, ind, da, fonts)
 	if err != nil {
 		return err
 	}
@@ -1002,11 +979,11 @@ func refreshListBoxAP(ctx *model.Context, d types.Dict, opts []string, ind types
 	return updateForm(ctx.XRefTable, bb, irN)
 }
 
-func EnsureListBoxAP(ctx *model.Context, d types.Dict, opts []string, ind types.Array, fonts map[string]types.IndirectRef) error {
+func EnsureListBoxAP(ctx *model.Context, d types.Dict, opts []string, ind types.Array, da *string, fonts map[string]types.IndirectRef) error {
 
 	apd := d.DictEntry("AP")
 	if apd == nil {
-		return renderListBoxAP(ctx, d, opts, ind, fonts)
+		return renderListBoxAP(ctx, d, opts, ind, da, fonts)
 	}
 
 	irN := apd.IndirectRefEntry("N")
@@ -1014,5 +991,5 @@ func EnsureListBoxAP(ctx *model.Context, d types.Dict, opts []string, ind types.
 		return nil
 	}
 
-	return refreshListBoxAP(ctx, d, opts, ind, fonts, irN)
+	return refreshListBoxAP(ctx, d, opts, ind, da, fonts, irN)
 }
